//
//  SCAdConfiguration.h
//  SmartclipSDKiOS
//
//  Copyright © 2018 smartclip. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@class SCAdEnvironment, SCAdVariants, UIColor;

typedef enum SCClickType {
    NotClickable,
    ClickableOnFullArea,
    ClickableOnAssociatedButtonOrLink,
    ClickableWithConfirmationDialog
} SCClickType;

typedef enum SCOnEndBehavior {
    Nothing,
    Collapse,
    Repeat
} SCOnEndBehavior;

/**
 * This class is used for configuring the advertisement behavior
 */
@interface SCAdConfiguration : NSObject
/// The request url for you advertisement content
@property (nonatomic, copy) NSString *adURL;
/// BundleId of the app
@property (nonatomic, copy) NSString* bundleId;
/// AdvertiserId
@property (nonatomic, copy) NSString* advertisementId;
/// Use this to enable bitrate calculation, or set desiredBitrate
@property (nonatomic, strong) SCAdEnvironment* environment;
/// If you use opener, closer or bumper, SCAdVariants is the place to define them
@property (nonatomic, strong) SCAdVariants* variants;
/// Use this property to specify a custom title for the ad.
@property (nonatomic, copy) NSString *customTitle;
/// Use this property to specify a custom title color for the ad.
@property (nonatomic, strong) UIColor *customTitleColor;
/// Use this property to specify a custom progress bar color for the ad.
@property (nonatomic, strong) UIColor *customProgressBarColor;
/// You can prevent ad skipping with this boolean value, defaults to true
@property (nonatomic)         BOOL     allowAdSkipping;
/// You can define an offset value, when you want to allow ad skipping (defaults to -1, meaning never)
@property (nonatomic)         NSInteger skipOffset;
/// `true` if the audio of the advertisement should be muted from the beginning. Defaulting to `false`.
@property (nonatomic)         BOOL      initialMuted;
/// `true` to show the mute button. Defaulting to `true`.
@property (nonatomic)         BOOL      showMuteToggleButton;
/// name of the image asset used for the off state of the sound button
@property (nonatomic, copy) NSString   *soundButtonOffImageName;
/// name of the image asset used for the on state of the sound button
@property (nonatomic, copy) NSString   *soundButtonOnImageName;
/// message to be displayed on the clickThrough dialog (default: "Open in Browser?")
@property (nonatomic, copy) NSString    *clickThroughDialogMessage;
/// string to be displayed on the clickThrough dialog`s positive answer button (default: "YES")
@property (nonatomic, copy) NSString    *clickThroughPositiveAnswer;
/// string to be displayed on the clickThrough dialog`s negative answer button (default: "NO")
@property (nonatomic, copy) NSString    *clickThroughNegativeAnswer;
/// clickType for clickThrough handling (default: ClickableWithConfirmationDialog)
@property (nonatomic) enum SCClickType  clickType;
/// onEndBehavior defines the behavior at the end of an (outstream) ad (nothing, collapse, repeat)
@property (nonatomic) enum SCOnEndBehavior onEndBehavior;
/// name of the image asset used for the replay button (outstream only)
@property (nonatomic, copy) NSString    *replayButtonImageName;
/// name of OMID Partner for adVerification
@property (nonatomic, copy) NSString    *omidPartnerName;
/// OMID version string for adVerification
@property (nonatomic, copy) NSString    *omidVersion;
/// force opener playback
@property (nonatomic) BOOL forceOpener;
/// force closer playback
@property (nonatomic) BOOL forceCloser;
/// force bumper playback
@property (nonatomic) BOOL forceBumper;
/// threshold value of the percentage of the adView that needs to be visible to play the ad (only needed for outstream)
/// defaults to 50%. values >= 100% are clamped to 99% a value of 0% will be changed to 1%
@property (nonatomic) NSUInteger visibilityThreshold;

/// The default configuration can be accessed through this static method
+ (SCAdConfiguration*)defaultConfigurationWith:(NSString*)requestURL variants:(SCAdVariants*)variants;
/// Default configuration initialized with the given SCAdEnvironment values
+ (SCAdConfiguration*)defaultConfigurationWith:(NSString*)requestURL variants:(SCAdVariants*)variants environment:(SCAdEnvironment*)environment;
/// defaultInstreamConfiguration for use with sequencer
+ (SCAdConfiguration*)defaultInstreamConfigurationWith:(SCAdEnvironment*)environment;
/// defaultOutstreamConfiguration for use with sequencer
+ (SCAdConfiguration*)defaultOutstreamConfigurationWith:(SCAdEnvironment*)environment;
///SpotXSDK version string
+ (NSString*)sdkVersionString;
///OMIDSDK version string
+ (NSString*)omidSDKVersionString;
@end

NS_ASSUME_NONNULL_END
